@@ -1,9 +1,4 @@
 """Constants for 2N library."""
-import asyncio
-import aiohttp
-
-CONNECT_ERRORS = (aiohttp.ClientError, asyncio.TimeoutError, OSError)
-
 HTTP_CALL_TIMEOUT = 10
 CONTENT_TYPE = "application/json"
 
@@ -12,4 +7,4 @@ API_SYSTEM_STATUS = "/api/system/status"
 API_SYSTEM_RESTART = "/api/system/restart"
 API_SWITCH_STATUS = "/api/switch/status"
 API_SWITCH_CONTROL = "/api/switch/ctrl"
-API_AUDIO_TEST = "/api/audio/test"
\ No newline at end of file
+API_AUDIO_TEST = "/api/audio/test"
